@@ -1,6 +1,8 @@
 from ..filehandler import FileHandler
 from portalocker import Lock
 from ..util import DEFAULT_TIMEOUT, DEFAULT_CHECK_INTERVAL, DEFAULT_FAIL_WHEN_LOCKED, LOCK_METHOD
+from gc import collect
+from copy import deepcopy
 
 
 class OpenReader(FileHandler):
@@ -23,19 +25,24 @@ class OpenReader(FileHandler):
         row_num = 0
         header = None
 
-        with Lock(filename=self.file_path, mode=self.mode, timeout=self.timeout, check_interval=self.check_interval,
-                  fail_when_locked=self.fail_when_locked, flags=self.flags) as lines:
-            for line in lines:
-                data.append(line)
+        try:
+            with Lock(filename=self.file_path, mode=self.mode, timeout=self.timeout, check_interval=self.check_interval,
+                      fail_when_locked=self.fail_when_locked, flags=self.flags) as lines:
+                for line in lines:
+                    data.append(line)
 
-                if buffer <= len(data):
-                    handler(self.file_path, data, row_num - len(data) + 1, row_num, **self.kwargs)
-                    data.clear()
+                    if buffer <= len(data):
+                        handler(deepcopy(self.file_path), deepcopy(data), deepcopy(row_num - len(data) + 1),
+                                deepcopy(row_num), **self.kwargs)
+                        data.clear()
 
-                row_num += 1
+                    row_num += 1
 
-        if data:
-            row_num -= 1
-            handler(self.file_path, data, row_num - len(data) + 1, row_num, **self.kwargs)
-        else:
-            return data
+            if data:
+                row_num -= 1
+                handler(deepcopy(self.file_path), deepcopy(data), deepcopy(row_num - len(data) + 1),
+                        deepcopy(row_num), **self.kwargs)
+            else:
+                return data
+        finally:
+            collect()
