@@ -20,7 +20,7 @@ class SQLConfig(BaseSQLConfig, PickleMixIn):
     config_types = ['sql', 'accdb', 'dsn', 'conn_str']
 
     def __init__(self, conn_type=None, conn_str=None, server=None, database=None, credentials=None, accdb_fp=None,
-                 dsn_name=None, autocommit=True):
+                 dsn_name=None, autocommit=False):
         """
         Types of possible SQL connections:
             * conn_type & conn_str
@@ -35,7 +35,7 @@ class SQLConfig(BaseSQLConfig, PickleMixIn):
         :param credentials: (Optional) Credentials instance class
         :param accdb_fp: (Optional) Access database filepath
         :param dsn_name: (Optional) DSN name
-        :param autocommit: (True/False) New instance will auto commit transactions [Default True]
+        :param autocommit: (True/False) New instance will auto commit transactions [Default False]
         """
 
         self.conn_type = None
