@@ -236,8 +236,8 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
 
         return registerhandler
 
-    def sql_execute(self, query_str, execute=False, queue_cursor=False, new_engine=False, csv_path=None,
-                    csv_replace=False, delimiter=',', quotechar='"', quoting=QUOTE_ALL, **kwargs):
+    def sql_execute(self, query_str, execute=False, queue_cursor=False, new_engine=False, file_path=None,
+                    file_replace=False, file_params={}, **kwargs):
         """
         Execute or Query SQL query statement. This command can be multi-threaded in a cursor queue
 
@@ -245,11 +245,9 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
         :param execute: [Optional] (True/False) Choose to execute or query results
         :param queue_cursor: [Optional] (True/False) Add to multi-thread queue
         :param new_engine: [Optional] (True/False) creates new engine for threading
-        :param csv_path: File path where data is stored at for csv file
-        :param csv_replace: (Optional) [True/False] Replace csv file if exists
-        :param delimiter: Data seperator to delimit columns
-        :param quotechar: Quote Character to wrap values with
-        :param quoting: csv quote mode
+        :param file_path: File path where data is stored at for csv file
+        :param file_replace: (Optional) [True/False] Replace csv file if exists
+        :param file_params: (Optional) [dict val] Keywords delimiter, quotechar, quoting
         :param kwargs: Kwarg values
 
         :return: Returns Cursor class if queue_cursor is set to False
@@ -263,20 +261,20 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
             keep_engine_alive = True
 
         if new_engine:
-            return self.__execute_sql(engine, spid, keep_engine_alive, query_str, execute, queue_cursor, csv_path,
-                               csv_replace, delimiter, quotechar, quoting, **kwargs)
+            return self.__execute_sql(engine, spid, keep_engine_alive, query_str, execute, queue_cursor, file_path,
+                                      file_replace, file_params, **kwargs)
         else:
             with self.__engine_lock:
-                return self.__execute_sql(engine, spid, keep_engine_alive, query_str, execute, queue_cursor, csv_path,
-                                   csv_replace, delimiter, quotechar, quoting, **kwargs)
+                return self.__execute_sql(engine, spid, keep_engine_alive, query_str, execute, queue_cursor, file_path,
+                                          file_replace, file_params, **kwargs)
 
     def __execute_sql(self, engine, spid, keep_engine_alive, query_str, execute=False, queue_cursor=False,
-                      csv_path=None, csv_replace=False, delimiter=',', quotechar='"', quoting=QUOTE_ALL, **kwargs):
+                      file_path=None, file_replace=False, file_params={}, **kwargs):
         from ..sql.cursor import SQLCursor
 
         if queue_cursor:
-            params = dict(query_str=query_str, execute=execute, handlers=self.__sql_handlers, csv_path=csv_path,
-                          csv_replace=csv_replace, delimiter=delimiter, quotechar=quotechar, quoting=quoting)
+            params = dict(query_str=query_str, execute=execute, handlers=self.__sql_handlers, file_path=file_path,
+                          file_replace=file_replace, file_params=file_params)
             cursor = SQLCursor(engine_type=self.engine_type, engine=engine, spid=spid, engine_class=self,
                                action="execute", action_params=params, keep_engine_alive=keep_engine_alive)
 
@@ -293,8 +291,7 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
                 try:
                     cursor.start()
                     cursor.execute(query_str=query_str, execute=execute, handler=handler, buffer=buffer,
-                                   csv_path=csv_path, csv_replace=csv_replace, delimiter=delimiter,
-                                   quotechar=quotechar, quoting=quoting, **kwargs)
+                                   file_path=file_path, file_replace=file_replace, file_params=file_params, **kwargs)
                     cursor.join()
                 except Exception as e:
                     cursor.close()
@@ -307,8 +304,8 @@ class SQLEngineClass(BaseSQLEngineClass, PickleMixIn):
 
             try:
                 cursor.start()
-                cursor.execute(query_str=query_str, execute=execute, csv_path=csv_path, csv_replace=csv_replace,
-                               delimiter=delimiter, quotechar=quotechar, quoting=quoting, **kwargs)
+                cursor.execute(query_str=query_str, execute=execute, file_path=file_path, file_replace=file_replace,
+                               file_params=file_params, **kwargs)
                 cursor.join()
             except:
                 cursor.close()
